import Matercolor from 'matercolors';
export declare const prefix = "hb";
export declare const levels: readonly [50, 100, 200, 300, 400, 500, 600, 700, 800, 900];
export type Level = (typeof levels)[number];
export declare const verticalAligns: readonly ["middle", "top", "bottom"];
export type VerticalAlign = (typeof verticalAligns)[number];
export declare const horizonAligns: readonly ["center", "right", "left"];
export type HorizonAlign = (typeof horizonAligns)[number];
export declare const sizes: readonly ["xsmall", "small", "medium", "large", "xlarge"];
export type Size = (typeof sizes)[number];
export declare const systemColors: readonly ["black", "brown", "yellow", "red", "green", "blue", "purple"];
export type SystemColor = (typeof systemColors)[number];
export declare const serviceColors: readonly ["heybit", "harvest", "reward"];
export type ServiceColor = (typeof serviceColors)[number];
export type CreateColor = SystemColor | ServiceColor;
export type AllColor = Record<CreateColor, Matercolor>;
export declare const systemThemes: readonly ["primary", "secondary", "success", "warning", "danger", "info"];
export type SystemTheme = (typeof systemThemes)[number];
export declare const createColors: Record<CreateColor, string>;
export declare const statusColors: Record<SystemTheme, string>;
export declare const primaryColors: Record<CreateColor, string>;
export declare const colorPalette: AllColor;
export declare const basicVariables: {
    font: {
        family: string;
        color: {
            void: string;
            solid: string;
        };
        size: number;
    };
    size: {
        xlarge: number;
        large: number;
        medium: number;
        small: number;
        xsmall: number;
    };
    layout: {
        gutter: number;
        media: number;
        'content-width': {
            '--mobile': number;
            '--desktop': number;
        };
    };
    border: {
        width: number;
        color: string;
        radius: number;
    };
    background: {
        color: string;
    };
    transition: {
        duration: {
            '--ms': string;
        };
        type: string;
        'delay-start': {
            '--ms': string;
        };
        'delay-end': {
            '--ms': string;
        };
    };
};
export declare const componentVariables: {
    dim: {
        background: {
            color: string;
        };
    };
    list: {
        height: number;
        padding: {
            right: number;
            left: number;
        };
        font: {
            size: number;
        };
        border: {
            width: number;
            color: string;
        };
    };
    icon: {
        color: string;
        size: {
            xlarge: number;
            large: number;
            medium: number;
            small: number;
            xsmall: number;
        };
    };
    input: {
        minHeight: number;
        maxHeight: number;
        border: {
            width: number;
            'width--error': number;
            'width--focus': number;
            color: string;
            'color--error': string;
            'color--disabled': string;
            'color--focus': string;
        };
        padding: {
            top: number;
            bottom: number;
            right: number;
            left: number;
        };
        font: {
            size: number;
            color: {
                '--placeholder': string;
            };
        };
    };
    button: {
        padding: {
            right: number;
            left: number;
        };
        font: {
            size: number;
        };
    };
    modal: {
        width: {
            sheet: number;
            dialog: number;
        };
        margin: number;
        background: string;
        dialog: {
            'padding-top': number;
            'padding-right': number;
            'padding-bottom': number;
            'padding-left': number;
        };
        'sheet-dialog': {
            'padding-top': number;
            'padding-right': number;
            'padding-bottom': number;
            'padding-left': number;
        };
    };
    spinner: {
        color: string;
        size: {
            xlarge: number;
            large: number;
            medium: number;
            small: number;
            xsmall: number;
        };
    };
    select: {
        font: {
            size: number;
        };
    };
    toast: {
        'max-width': number;
        'min-height': number;
        margin: {
            left: number;
            right: number;
            top: number;
            bottom: number;
        };
        padding: {
            top: number;
            bottom: number;
            right: number;
            left: number;
        };
        positive: {
            icon: string;
            color: string;
        };
        negative: {
            icon: string;
            color: string;
        };
    };
    header: {
        height: {
            '--mobile': number;
            '--desktop': number;
        };
        logo: {
            width: {
                '--mobile': number;
                '--desktop': number;
            };
        };
    };
};
